@@ -20,14 +20,7 @@
 #include "elisa_settings.h"
 #include <KAuthorized>
 #include <KLocalizedString>
-
-#if KFConfigWidgets_FOUND
-#include <KStandardAction>
-#endif
-
-#if KFDBusAddons_FOUND
-#include <KDBusService>
-#endif
+#include <KStandardActions>
 
 #if defined KFXmlGui_FOUND
 #include <KActionCollection>
@@ -90,33 +83,11 @@ public:
 
     std::unique_ptr<ManageHeaderBar> mManageHeaderBar;
 
-    QQmlEngine *mEngine = nullptr;
-
     QFileSystemWatcher mConfigFileWatcher;
 
     KColorSchemeManager *mSchemes = nullptr;
 };
 
-ElisaApplication *ElisaApplication::create(QQmlEngine *engine, QJSEngine *scriptEngine)
-{
-    Q_UNUSED(scriptEngine)
-    auto newApplication = std::make_unique<ElisaApplication>();
-
-#if KFDBusAddons_FOUND
-    auto *elisaService = new KDBusService(KDBusService::Unique, newApplication.get());
-#endif
-
-#if KFDBusAddons_FOUND
-    QObject::connect(elisaService, &KDBusService::activateActionRequested, newApplication.get(), &ElisaApplication::activateActionRequested);
-    QObject::connect(elisaService, &KDBusService::activateRequested, newApplication.get(), &ElisaApplication::activateRequested);
-    QObject::connect(elisaService, &KDBusService::openRequested, newApplication.get(), &ElisaApplication::openRequested);
-#endif
-
-    newApplication->setQmlEngine(engine);
-
-    return newApplication.release();
-}
-
 ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::make_unique<ElisaApplicationPrivate>(this))
 {
     auto configurationFileName = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
@@ -161,42 +132,37 @@ void ElisaApplication::setupActions(const QString &actionName)
 {
 #if KFXmlGui_FOUND
     if (actionName == QLatin1String("file_quit")) {
-        auto quitAction = KStandardAction::quit(QCoreApplication::instance(), &QCoreApplication::quit, &d->mCollection);
+        auto quitAction = KStandardActions::quit(QCoreApplication::instance(), &QCoreApplication::quit, &d->mCollection);
         d->mCollection.addAction(actionName, quitAction);
     }
 
-    if (actionName == QLatin1String("help_contents") && KAuthorized::authorizeAction(actionName)) {
-        auto handBookAction = KStandardAction::helpContents(this, &ElisaApplication::appHelpActivated, &d->mCollection);
-        d->mCollection.addAction(handBookAction->objectName(), handBookAction);
-    }
-
     if (actionName == QLatin1String("help_report_bug") && KAuthorized::authorizeAction(actionName) && !KAboutData::applicationData().bugAddress().isEmpty()) {
-        auto reportBugAction = KStandardAction::reportBug(this, &ElisaApplication::reportBug, &d->mCollection);
+        auto reportBugAction = KStandardActions::reportBug(this, &ElisaApplication::reportBug, &d->mCollection);
         d->mCollection.addAction(reportBugAction->objectName(), reportBugAction);
     }
 
     if (actionName == QLatin1String("help_about_app") && KAuthorized::authorizeAction(actionName)) {
-        auto aboutAppAction = KStandardAction::aboutApp(this, &ElisaApplication::openAboutAppPage, this);
+        auto aboutAppAction = KStandardActions::aboutApp(this, &ElisaApplication::openAboutAppPage, this);
         d->mCollection.addAction(aboutAppAction->objectName(), aboutAppAction);
     }
 
     if (actionName == QLatin1String("help_about_kde") && KAuthorized::authorizeAction(actionName)) {
-        auto aboutKDEAction = KStandardAction::aboutKDE(this, &ElisaApplication::openAboutKDEPage, this);
+        auto aboutKDEAction = KStandardActions::aboutKDE(this, &ElisaApplication::openAboutKDEPage, this);
         d->mCollection.addAction(aboutKDEAction->objectName(), aboutKDEAction);
     }
 
     if (actionName == QLatin1String("options_configure") && KAuthorized::authorizeAction(actionName)) {
-        auto preferencesAction = KStandardAction::preferences(this, &ElisaApplication::configureElisa, this);
+        auto preferencesAction = KStandardActions::preferences(this, &ElisaApplication::configureElisa, this);
         d->mCollection.addAction(preferencesAction->objectName(), preferencesAction);
     }
 
     if (actionName == QLatin1String("options_configure_keybinding") && KAuthorized::authorizeAction(actionName)) {
-        auto keyBindingsAction = KStandardAction::keyBindings(this, &ElisaApplication::configureShortcuts, this);
+        auto keyBindingsAction = KStandardActions::keyBindings(this, &ElisaApplication::configureShortcuts, this);
         d->mCollection.addAction(keyBindingsAction->objectName(), keyBindingsAction);
     }
 
     if (actionName == QLatin1String("go_back") && KAuthorized::authorizeAction(actionName)) {
-        auto goBackAction = KStandardAction::back(this, &ElisaApplication::goBack, this);
+        auto goBackAction = KStandardActions::back(this, &ElisaApplication::goBack, this);
         d->mCollection.addAction(goBackAction->objectName(), goBackAction);
     }
 
@@ -237,7 +203,7 @@ void ElisaApplication::setupActions(const QString &actionName)
     }
 
     if (actionName == QLatin1String("edit_find") && KAuthorized::authorizeAction(actionName)) {
-        auto findAction = KStandardAction::find(this, &ElisaApplication::find, this);
+        auto findAction = KStandardActions::find(this, &ElisaApplication::find, this);
         d->mCollection.addAction(findAction->objectName(), findAction);
     }
 
@@ -308,11 +274,6 @@ void ElisaApplication::openRequested(const QList<QUrl> &uris)
     openFiles(uris);
 }
 
-void ElisaApplication::appHelpActivated()
-{
-    QDesktopServices::openUrl(QUrl(QStringLiteral("help:/")));
-}
-
 void ElisaApplication::reportBug()
 {
 #if KFXmlGui_FOUND
@@ -413,11 +374,6 @@ void ElisaApplication::initialize()
     Q_EMIT initializationDone();
 }
 
-void ElisaApplication::setQmlEngine(QQmlEngine *engine)
-{
-    d->mEngine = engine;
-}
-
 void ElisaApplication::initializeModels()
 {
     d->mMusicManager = std::make_unique<MusicListenersManager>();
